@@ -98,6 +98,17 @@ gbf_project_refresh (GbfProject *project,
 	GBF_PROJECT_GET_CLASS (project)->refresh (project, error);
 }
 
+GbfProjectCapabilities
+gbf_project_get_capabilities (GbfProject *project,
+		     GError    **error)
+{
+	g_return_val_if_fail (project != NULL, GBF_PROJECT_CAN_ADD_NONE);
+	g_return_val_if_fail (GBF_IS_PROJECT (project), GBF_PROJECT_CAN_ADD_NONE);
+	g_return_val_if_fail (error == NULL || *error == NULL, GBF_PROJECT_CAN_ADD_NONE);
+
+	return GBF_PROJECT_GET_CLASS (project)->get_capabilities (project, error);
+}
+
 /* Build. */
 GList *
 gbf_project_get_build_targets (GbfProject *project,
@@ -410,6 +421,28 @@ gbf_project_configure (GbfProject *project, GError **error)
 	return GBF_PROJECT_GET_CLASS (project)->configure (project, error);
 }
 
+GList *
+gbf_project_get_config_modules   (GbfProject *project, GError **error)
+{
+	g_return_val_if_fail (project != NULL, NULL);
+	g_return_val_if_fail (GBF_IS_PROJECT (project), NULL);
+	
+	return GBF_PROJECT_GET_CLASS (project)->get_config_modules (project, error);
+}
+
+GList *
+gbf_project_get_config_packages  (GbfProject *project,
+																	const gchar* module,
+																	GError **error)
+{
+	g_return_val_if_fail (project != NULL, NULL);
+	g_return_val_if_fail (module != NULL, NULL);
+	g_return_val_if_fail (GBF_IS_PROJECT (project), NULL);
+	
+	return GBF_PROJECT_GET_CLASS (project)->get_config_packages (project, module,
+																															 error);
+}
+
 /* Types. */
 const gchar * 
 gbf_project_name_for_type (GbfProject  *project,
